@@ -1,6 +1,7 @@
 from dvc.output.base import BaseOutput
-from dvc.remote.ssh import SSHRemote
+
+from ..tree.ssh import SSHTree
 
 
 class SSHOutput(BaseOutput):
-    REMOTE = SSHRemote
+    TREE_CLS = SSHTree
