@@ -76,6 +76,9 @@ class Experiments:
     STASH_EXPERIMENT_RE = re.compile(
         r"(?:On \(.*\): )dvc-exp-(?P<baseline_rev>[0-9a-f]+)$"
     )
+    BRANCH_RE = re.compile(
+        r"^(?P<baseline_rev>[a-f0-9]{7})-(?P<exp_sha>[a-f0-9]+)$"
+    )
 
     def __init__(self, repo):
         from dvc.lock import make_lock
@@ -512,7 +515,7 @@ class Experiments:
         """Checkout an experiment to the user's workspace."""
         from git.exc import GitCommandError
 
-        from dvc.repo.checkout import _checkout as dvc_checkout
+        from dvc.repo.checkout import checkout as dvc_checkout
 
         self._check_baseline(rev)
         self._scm_checkout(rev)
@@ -557,10 +560,43 @@ class Experiments:
         # to prefer the applied experiment changes over stashed workspace
         # changes. git stash doesn't support merge strategy parameters, but we
         # can do it ourselves with checkout/reset.
+        from git.exc import GitCommandError
+
         logger.debug("Unstashing workspace changes.")
-        self.repo.scm.repo.git.checkout("--ours", "stash@{0}", "--", ".")
-        self.repo.scm.repo.git.reset("HEAD")
-        self.repo.scm.repo.git.stash("drop", "stash@{0}")
+        git_repo = self.repo.scm.repo.git
+
+        # stage workspace changes, then apply stashed changes on top
+        git_repo.add(A=True)
+        try:
+            git_repo.stash("apply", "stash@{0}")
+        except GitCommandError:
+            # stash apply will return error code on merge conflicts,
+            # prefer workspace changes over stash changes
+            git_repo.checkout("--ours", "--", ".")
+
+        # unstage changes and drop the stash entry
+        git_repo.reset("HEAD")
+        git_repo.stash("drop", "stash@{0}")
+
+    @scm_locked
+    def get_baseline(self, rev):
+        """Return the baseline rev for an experiment rev."""
+        from git.exc import GitCommandError
+
+        rev = self.scm.resolve_rev(rev)
+        try:
+            name = self.scm.repo.git.name_rev(rev, name_only=True)
+        except GitCommandError:
+            return None
+        if not name:
+            return None
+        if name in ("undefined", "stash"):
+            _, baseline = self.stash_revs.get(rev, (None, None))
+            return baseline
+        m = self.BRANCH_RE.match(name)
+        if m:
+            return self.scm.resolve_rev(m.group("baseline_rev"))
+        return None
 
     def checkout(self, *args, **kwargs):
         from dvc.repo.experiments.checkout import checkout
