@@ -1,13 +1,11 @@
-import yaml
 import logging
 import os
 
-from dvc.path_info import PathInfo
-from dvc.compat import fspath_py35
 from dvc.exceptions import NoMetricsError
+from dvc.path_info import PathInfo
 from dvc.repo import locked
-from dvc.repo.tree import RepoTree
-
+from dvc.tree.repo import RepoTree
+from dvc.utils.serialize import YAMLFileCorruptedError, load_yaml
 
 logger = logging.getLogger(__name__)
 
@@ -37,7 +35,7 @@ def _collect_metrics(repo, targets, recursive):
     return list(filter(_filter, metrics))
 
 
-def _extract_metrics(metrics):
+def _extract_metrics(metrics, path, rev):
     if isinstance(metrics, (int, float)):
         return metrics
 
@@ -46,9 +44,18 @@ def _extract_metrics(metrics):
 
     ret = {}
     for key, val in metrics.items():
-        m = _extract_metrics(val)
+        m = _extract_metrics(val, path, rev)
         if m:
             ret[key] = m
+        else:
+            logger.debug(
+                "Could not parse '%s' metric from '%s' at '%s' "
+                "due to its unsupported type: '%s'",
+                key,
+                path,
+                rev,
+                type(val).__name__,
+            )
 
     return ret
 
@@ -58,22 +65,20 @@ def _read_metrics(repo, metrics, rev):
 
     res = {}
     for metric in metrics:
-        if not tree.exists(fspath_py35(metric)):
+        if not tree.exists(metric):
             continue
 
-        with tree.open(fspath_py35(metric), "r") as fobj:
-            try:
-                # NOTE this also supports JSON
-                val = yaml.safe_load(fobj)
-            except yaml.YAMLError:
-                logger.debug(
-                    "failed to read '%s' on '%s'", metric, rev, exc_info=True
-                )
-                continue
+        try:
+            val = load_yaml(metric, tree=tree)
+        except (FileNotFoundError, YAMLFileCorruptedError):
+            logger.debug(
+                "failed to read '%s' on '%s'", metric, rev, exc_info=True
+            )
+            continue
 
-            val = _extract_metrics(val)
-            if val:
-                res[str(metric)] = val
+        val = _extract_metrics(val, metric, rev)
+        if val:
+            res[str(metric)] = val
 
     return res
 
@@ -89,6 +94,7 @@ def show(
     all_commits=False,
 ):
     res = {}
+    metrics_found = False
 
     for rev in repo.brancher(
         revs=revs,
@@ -97,21 +103,35 @@ def show(
         all_commits=all_commits,
     ):
         metrics = _collect_metrics(repo, targets, recursive)
+
+        if not metrics_found and metrics:
+            metrics_found = True
+
         vals = _read_metrics(repo, metrics, rev)
 
         if vals:
             res[rev] = vals
 
     if not res:
-        raise NoMetricsError()
+        if metrics_found:
+            msg = (
+                "Could not parse metric files. Use `-v` option to see more "
+                "details."
+            )
+        else:
+            msg = (
+                "no metric files in this repository. Use `-m/-M` options for "
+                "`dvc run` to mark stage outputs as  metrics."
+            )
+        raise NoMetricsError(msg)
 
-    # Hide working tree metrics if they are the same as in the active branch
+    # Hide workspace metrics if they are the same as in the active branch
     try:
         active_branch = repo.scm.active_branch()
     except TypeError:
         pass  # Detached head
     else:
-        if res.get("working tree") == res.get(active_branch):
-            res.pop("working tree", None)
+        if res.get("workspace") == res.get(active_branch):
+            res.pop("workspace", None)
 
     return res
