@@ -1,12 +1,14 @@
-from funcy import decorator
 from functools import wraps
 
+from funcy import decorator
+
 
 @decorator
 def rwlocked(call, read=None, write=None):
     import sys
-    from dvc.rwlock import rwlock
+
     from dvc.dependency.repo import RepoDependency
+    from dvc.rwlock import rwlock
 
     if read is None:
         read = []
@@ -14,7 +16,7 @@ def rwlocked(call, read=None, write=None):
     if write is None:
         write = []
 
-    stage = call._args[0]
+    stage = call._args[0]  # pylint: disable=protected-access
 
     assert stage.repo.lock.is_locked
 
@@ -39,7 +41,7 @@ def unlocked_repo(f):
     def wrapper(stage, *args, **kwargs):
         stage.repo.state.dump()
         stage.repo.lock.unlock()
-        stage.repo._reset()
+        stage.repo._reset()  # pylint: disable=protected-access
         try:
             ret = f(stage, *args, **kwargs)
         finally:
